pub trait Gate:
Send
+ Sync
+ Debug {
// Required method
fn execute_gate<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
agent_id: Uuid,
task_prompt: &'life1 str,
suggested_output: &'life2 str,
confidence: f64,
capabilities: Vec<Capability>,
) -> Pin<Box<dyn Future<Output = EvidenceCapsule> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
}Expand description
Exogenous Gate Decision Boundary
A Gate acts as a continuation authority, deciding whether an agent’s output is “Safe”, “Valid”, or “Audit-Compliant”.
Required Methods
Sourcefn execute_gate<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
agent_id: Uuid,
task_prompt: &'life1 str,
suggested_output: &'life2 str,
confidence: f64,
capabilities: Vec<Capability>,
) -> Pin<Box<dyn Future<Output = EvidenceCapsule> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn execute_gate<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
agent_id: Uuid,
task_prompt: &'life1 str,
suggested_output: &'life2 str,
confidence: f64,
capabilities: Vec<Capability>,
) -> Pin<Box<dyn Future<Output = EvidenceCapsule> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Evaluate the current execution state and return a signed Evidence Capsule.